"""
This type stub file was generated by pyright.
"""

from ollama import Client as _OllamaClient
from fundar_llms.api.interface import Base64, BaseResponse, PlainPromptInterface, response_dataclass_options
from typing import Any, Optional
from dataclasses import dataclass

def dict_dif(a, b): # -> dict[Any, Any]:
    ...

@dataclass(**response_dataclass_options)
class OllamaResponse(BaseResponse):
    created_at: str
    prompt_eval_count: int
    prompt_eval_duration: int
    eval_count: int
    eval_duration: int
    ...


OLLAMA_DEFAULT_OPTIONS = ...
class OllamaClient(PlainPromptInterface, _OllamaClient):
    def list_models(self, max_vram=...): # -> list[Any]:
        ...
    
    def generate(self, model: str, prompt: str, raw: Optional[bool] = ..., image: Optional[Base64] = ..., suffix: Optional[str] = ..., format: Optional[str] = ..., system: Optional[str] = ..., context: Optional[Any] = ..., stream: Optional[bool] = ..., num_ctx: Optional[int] = ..., num_predict: Optional[int] = ..., temperature: Optional[float] = ..., top_k: Optional[int] = ..., top_p: Optional[float] = ..., *args, **kwargs) -> Any:
        ...
    


