"""
This type stub file was generated by pyright.
"""

from dataclasses import dataclass
from typing import Optional

tokenizer_model_dataclass_options = ...
auto_tokenizer_ = ...
@dataclass(**tokenizer_model_dataclass_options)
class TokenizerModel:
    name: str
    needs_auth: bool = ...
    def __str__(self) -> str:
        ...
    
    def auto_tokenizer_from_pretrained(self):
        ...
    


DEFAULT_TOKENIZER_MAP = ...
def get_tokenizer(model_name: str, tokenizer_map: Optional[dict[str, TokenizerModel]] = ..., default: Optional[TokenizerModel] = ...) -> TokenizerModel:
    ...

