"""
This type stub file was generated by pyright.
"""

_is_cuda_available_ = ...
def is_cuda_available() -> bool:
    ...

def available_vram_nvidia_smi(): # -> tuple[int, int]:
    ...

def available_vram_torch(): # -> tuple[int, Any]:
    ...

def get_available_vram(): # -> tuple[int, int] | tuple[int, Any]:
    ...

