"""
This type stub file was generated by pyright.
"""

def umap_project_embeddings(umap_transform, embeddings, show_progress, strict: bool, dimensions: int): # -> NDArray[float64] | coo_matrix | Any | list[Any]:
    ...

def tsne_project_embeddings(tsne_transform, embeddings, show_progress):
    ...

def project_data(transform, embeddings, by: str = ..., show_progress: bool = ..., strict: bool = ..., dimensions: int = ...): # -> NDArray[float64] | coo_matrix | Any | list[Any]:
    ...

