"""
This type stub file was generated by pyright.
"""

from typing import ParamSpec, Sequence, TypeVar

P = ParamSpec('P')
T = TypeVar('T')
def flatten(nested_list: Sequence[Sequence[T]], max_level=...) -> Sequence[T]:
    ...

def split_list_into_chunks(lst: list[T], chunk_size: int): # -> list[list[T]]:
    ...

def allow_opaque_constructor(**objects): # -> Callable[..., Callable[P, T]]:
    ...

